Struct WriteOnlyAccess
Source pub struct WriteOnlyAccess();
An access marker type indicating that a port is only allowed to write values.
Formats the value using the given formatter.
Read more
A string representation for debug output.
Immutably borrows from an owned value.
Read more
Mutably borrows from an owned value.
Read more
Returns the argument unchanged.
Calls U::from(self).
That is, this conversion is whatever the implementation of
[From]<T> for U chooses to do.
The type returned in the event of a conversion error.
Performs the conversion.
The type returned in the event of a conversion error.
Performs the conversion.